@@ -11,7 +11,6 @@
 #' @param cluster_rows Logical indicating whether to cluster genes/rows (default: FALSE)
 #' @param cluster_cols Logical indicating whether to cluster conditions/columns (default: FALSE)
 #' @param show_gene_age Logical indicating whether to show gene age annotation (default: TRUE)
-#' @param show_phylostrata_legend Logical indicating whether to show the phylostratum legend (default: TRUE)
 #' @param show_gene_ids Logical indicating whether to show gene identifiers (default: FALSE)
 #' @param gene_annotation Data frame with custom gene annotations, rownames should match gene IDs (default: NULL)
 #' @param gene_annotation_colors Named list of color vectors for custom gene annotations (default: NULL)
@@ -64,7 +63,6 @@ plot_gene_heatmap <- S7::new_generic("plot_gene_heatmap", "phyex_set",
              cluster_rows = FALSE,
              cluster_cols = FALSE,
              show_gene_age = TRUE,
-             show_phylostrata_legend = TRUE,
              show_gene_ids = FALSE,
              gene_annotation = NULL,
              gene_annotation_colors = NULL,
@@ -87,7 +85,6 @@ plot_gene_heatmap <- S7::new_generic("plot_gene_heatmap", "phyex_set",
 #' @param cluster_rows Logical indicating whether to cluster genes/rows (default: FALSE)
 #' @param cluster_cols Logical indicating whether to cluster identities/columns (default: FALSE)
 #' @param show_gene_age Logical indicating whether to show gene age as row annotation (default: TRUE)
-#' @param show_phylostrata_legend Logical indicating whether to show the phylostratum legend (default: TRUE)
 #' @param show_gene_ids Logical indicating whether to show gene names (default: FALSE)
 #' @param gene_annotation Data frame with custom gene annotations, rownames should match gene IDs (default: NULL)
 #' @param gene_annotation_colors Named list of color vectors for custom gene annotations (default: NULL)
@@ -109,7 +106,6 @@ plot_gene_heatmap <- S7::new_generic("plot_gene_heatmap", "phyex_set",
                                    cluster_rows = FALSE,
                                    cluster_cols = FALSE,
                                    show_gene_age = TRUE,
-                                   show_phylostrata_legend = TRUE,
                                    show_gene_ids = FALSE,
                                    gene_annotation = NULL,
                                    gene_annotation_colors = NULL,
@@ -246,13 +242,7 @@ plot_gene_heatmap <- S7::new_generic("plot_gene_heatmap", "phyex_set",
             Phylostratum = ps_colors
         )
     }
-    
-    # Determine which legends to show
-    annotation_legend <- TRUE
-    if (show_gene_age && !show_phylostrata_legend && is.null(gene_annotation)) {
-        # Only hide legend if phylostratum is the only row annotation
-        annotation_legend <- FALSE
-    }
+
 
     p <- pheatmap::pheatmap(
         e,
@@ -264,7 +254,6 @@ plot_gene_heatmap <- S7::new_generic("plot_gene_heatmap", "phyex_set",
         annotation_row = annotation_row,
         annotation_col = annotation_col,
         annotation_colors = c(annotation_colors, annotation_col_colors),
-        annotation_legend = annotation_legend,
         silent = TRUE,
         ...
     ) |>
@@ -283,7 +272,6 @@ S7::method(plot_gene_heatmap, BulkPhyloExpressionSet) <- function(phyex_set,
                                                                  cluster_rows = FALSE,
                                                                  cluster_cols = FALSE,
                                                                  show_gene_age = TRUE,
-                                                                 show_phylostrata_legend = TRUE,
                                                                  show_gene_ids = FALSE,
                                                                  gene_annotation = NULL,
                                                                  gene_annotation_colors = NULL,
@@ -309,7 +297,6 @@ S7::method(plot_gene_heatmap, BulkPhyloExpressionSet) <- function(phyex_set,
         cluster_rows = cluster_rows,
         cluster_cols = cluster_cols,
         show_gene_age = show_gene_age,
-        show_phylostrata_legend = show_phylostrata_legend,
         show_gene_ids = show_gene_ids,
         gene_annotation = gene_annotation,
         gene_annotation_colors = gene_annotation_colors,
@@ -328,7 +315,6 @@ S7::method(plot_gene_heatmap, ScPhyloExpressionSet) <- function(phyex_set,
                                                                cluster_rows = FALSE,
                                                                cluster_cols = FALSE,
                                                                show_gene_age = TRUE,
-                                                               show_phylostrata_legend = TRUE,
                                                                show_gene_ids = FALSE,
                                                                gene_annotation = NULL,
                                                                gene_annotation_colors = NULL,
@@ -404,7 +390,6 @@ S7::method(plot_gene_heatmap, ScPhyloExpressionSet) <- function(phyex_set,
         cluster_rows = cluster_rows,
         cluster_cols = cluster_cols,
         show_gene_age = show_gene_age,
-        show_phylostrata_legend = show_phylostrata_legend,
         show_gene_ids = show_gene_ids,
         gene_annotation = gene_annotation,
         gene_annotation_colors = gene_annotation_colors,
